==> minitube_0.9.orig.tar.gz: minitube/locale/es.ts <==
<!DOCTYPE TS><TS>
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Esta es una edición «Prueba conceptual», no espere que sea perfecta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Envie sus informes de errores o sus ideas a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo supone un tiempo muy valioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;haga una donación a través de PayPal&lt;/a&gt; para colaborar con el desarrollo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icono diseñado por %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto aportado por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Compatibilidad con proxy HTTP aportado por %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia Publica General GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Que es lo que siempre quiso saber acerca de %1 y nunca se atrevió a preguntar</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Versión Windows construida por %1</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>No hay videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>No hay más videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Retroceder</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ir a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener la reproducción y volver a la vista de busqueda</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Escape</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Avanzar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar la reproducción</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Espacio</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Pantalla completa</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Abrir la pagina del video en YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Eliminarlos videos seleccionados de la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover A&amp;rriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover hacia arriba, en la lista de reproducción, los videos seleccionados</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover Aba&amp;jo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover hacia abajo, en la lista de reproducción, los videos seleccionados</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Hasta luego</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube en internet</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>D&amp;onar a través de PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoye el desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información acerca de %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Buscar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar el volumen</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presione %1 para aumentar el volumen, %2 para reducirlo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal:%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar la reproducción</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Salir de &amp;pantalla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>El volumen está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>El volumen no está silenciado</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>El video en alta definición está activado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>El video en alta definición está desactivado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>El vídeo actual es de alta definición</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>El vídeo actual no es de alta definición</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Limpiar palabras &amp;clave recientes</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Más destacados</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Está viendo %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizaciones</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Introduzca una palabra clave para empezar a ver videos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palabra clave reciente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Está disponible una nueva versión de %1. Por favor &lt;a href=&apos;%2&apos;&gt;actualice a la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sientase cómodo</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Error de red: %1 por %2</translation>
    </message>
</context>
</TS>

==> minitube_1.1.orig.tar.gz: minitube/locale/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Esta es una edición «Prueba conceptual», no espere que sea perfecta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Envie sus informes de errores o sus ideas a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo supone un tiempo muy valioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Por favor &lt;a href=&apos;%1&apos;&gt;haga una donación a través de PayPal&lt;/a&gt; para colaborar con el desarrollo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icono diseñado por %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto aportado por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Compatibilidad con proxy HTTP aportado por %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia Publica General GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Que es lo que siempre quiso saber acerca de %1 y nunca se atrevió a preguntar</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Versión Windows construida por %1</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Haga una &lt;a href=&apos;%1&apos;&gt;donación&lt;/a&gt; para ayudar en la continuación del desarrollo de %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>No hay videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>No hay más videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Atrás</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Retroceder</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Ir a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener la reproducción y volver a la vista de busqueda</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Escape</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Avanzar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar la reproducción</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Espacio</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Pantalla completa</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Abrir la pagina del video en YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Eliminarlos videos seleccionados de la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover A&amp;rriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover hacia arriba, en la lista de reproducción, los videos seleccionados</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover Aba&amp;jo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover hacia abajo, en la lista de reproducción, los videos seleccionados</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Hasta luego</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube en internet</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">D&amp;onar a través de PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoye el desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información acerca de %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Buscar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar el volumen</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presione %1 para aumentar el volumen, %2 para reducirlo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal:%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar la reproducción</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Salir de &amp;pantalla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>El volumen está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>El volumen no está silenciado</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">El video en alta definición está activado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">El video en alta definición está desactivado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">El vídeo actual es de alta definición</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">El vídeo actual no es de alta definición</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Limpiar palabras &amp;clave recientes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpiar el historial de búsquedas. No se puede deshacer.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Su intimidad ahora está segura
</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Abrir la página de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir a la página de videos YouTube y pausar la reproducción</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar el en&amp;lace de YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar el enlace actual de video de YouTube en el portapapeles</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar el &amp;URL de flujo de video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar el URL actual del flujo de video en el portapapeles</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Hacer una &amp;donación</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolución máxima de video fijada en %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Más destacados</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Está viendo %1</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ahora puede pegar el enlace de YouTube en otra aplicación</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ahora puede pegar el URl del flujo de video en otra aplicación</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>El enlace es válido sólo por un tiempo limitado.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizaciones</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Introduzca una palabra clave para empezar a ver videos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palabra clave reciente</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Está disponible una nueva versión de %1. Por favor &lt;a href=&apos;%2&apos;&gt;actualice a la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sientase cómodo</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Error de red: %1 por %2</translation>
    </message>
</context>
</TS>
